#################################################################

# NOTE: Before the code can be executed, the R working directory 
# *MUST* be set to the directory that contains the folder 
# 'suppmat2_hornungwrighttr':

# Remove '#' from the two lines below and replace 
# 'Z:/here/is/my/path/' by the path to the directory that 
# contains 'suppmat2_hornungwrighttr' ( the path 
# 'Z:/here/is/my/path/' *MUST* end with a slash / ):

# basedir <- "Z:/here/is/my/path/"
# setwd(basedir)

#################################################################


# Load in and prepare the results:


load("./suppmat2_hornungwrighttr/Results/scenariogridtwoblocks.Rda")

allinds <- 1:nrow(scenariogrid)

allresults <- list.files("./suppmat2_hornungwrighttr/Results/ResultsTwoBlocks")
indres <- gsub("res", "", allresults)
indres <- sort(as.numeric(gsub(".Rda", "", indres)))

(anymissing <- length(setdiff(allinds, indres)) > 0)

# --> No missing iterations.



Results <- list()

count <- 1

for(i in 1:nrow(scenariogrid)) {
  load(paste("./suppmat2_hornungwrighttr/Results/ResultsTwoBlocks/res", indres[count], ".Rda", sep=""))
  Results[[count]] <- res
  count <- count + 1
}


scenariogrid$method[scenariogrid$method=="randomsurvivalforest"] <- "RSF"





ytrue <- lapply(rapply(sapply(Results, function(x) x$ytrue), enquote, how="unlist"), eval)
ytruestatus <- lapply(rapply(sapply(Results, function(x) x$ytruestatus), enquote, how="unlist"), eval)

riskpreds <- lapply(rapply(sapply(Results, function(x) x$riskpreds), enquote, how="unlist"), eval)


paramvalues <- sapply(Results, function(x) x$paramvalues)
zeroparamvalues <- sapply(paramvalues, function(x) length(x)==0)
paramvalues[zeroparamvalues] <- as.list(rep(NA, sum(zeroparamvalues)))
paramvalues <- lapply(rapply(paramvalues, enquote, how="unlist"), eval)



mtrys <- sapply(Results, function(x) x$mtrys)
zeromtrys <- sapply(mtrys, function(x) length(x)==0)
mtrys[zeromtrys] <- as.list(rep(NA, sum(zeromtrys)))
mtrys <- lapply(rapply(mtrys, enquote, how="unlist"), eval)






# Compute the C index values from the raw results:


# First, check the cases for which the C index is not computable
# or result in 'NA':

options(warn=2)

cs <- list()

library("survcomp")
for(i in seq(along=ytrue)) {
  
  cs[[i]] <- try(concordance.index(x=riskpreds[[i]], surv.time=ytrue[[i]], surv.event=ytruestatus[[i]])$c.index)
  
}

options(warn=0)


table(sapply(cs, class))
table(sapply(cs, is.na))


all(scenariogrid[sapply(cs, class)=="try-error",]$dat=="PRAD.Rda")

# --> All iterations for which the C index could not be computed
# were obtained with the data set PRAD that was excluded from the analysis.


scenariogrid[sapply(cs, is.na) & scenariogrid$dat!="PRAD.Rda",]

nrow(scenariogrid[sapply(cs, is.na) & scenariogrid$dat!="PRAD.Rda",])
nrow(scenariogrid[scenariogrid$dat!="PRAD.Rda",])

nrow(scenariogrid[sapply(cs, is.na) & scenariogrid$dat!="PRAD.Rda",])/
  nrow(scenariogrid[scenariogrid$dat!="PRAD.Rda",])

# --> The cases for which the computed C index was 'NA' were
# very rare.




# --> Calculate the C index values:

library("survcomp")
results <- scenariogrid
results$cindex <- mapply(function(x, y, z) concordance.index(x=x, surv.time=y, surv.event=z)$c.index, riskpreds, ytrue, ytruestatus)
results$mtry <- unlist(mtrys)

results$seed <- NULL



# Calculate mean C index values per data set:

library("plyr")
resultsum <- ddply(results, .variables=c("method", "dat", "cvind"), .fun=summarise, cindex=mean(cindex, na.rm=TRUE))

resultsum$method <- factor(resultsum$method, levels=c("RSF", 
                                  "VarProb",
                                  "SplitWeights",
                                  "BlockVarSel",
                                  "RandomBlock",
                                  "BlockForest"))

datasets <- sort(unique(resultsum$dat))






# Calculate the mean C index values across data sets:

resultsumsum <- ddply(resultsum, .variables=c("method", "dat"), .fun=summarise, cindex=mean(cindex))

resultswide <- reshape(resultsumsum, idvar = c("dat"), timevar = "method", direction = "wide")
resultswide

resultswide2 <- resultswide[,-1]




# Result obtained with the data set PRAD that was excluded from
# the results:

resultswide[resultswide$dat=="PRAD.Rda",]



# Exclude data set PRAD:

results_withPRAD <- results
resultsum_withPRAD <- resultsum
resultsumsum_withPRAD <- resultsumsum
resultswide_withPRAD <- resultswide
resultswide2_withPRAD <- resultswide2
paramvalues_withPRAD <- paramvalues
mtrys_withPRAD <- mtrys

results <- results[results$dat!="PRAD.Rda",]
resultsum <- resultsum[resultsum$dat!="PRAD.Rda",]
resultsumsum <- resultsumsum[resultsumsum$dat!="PRAD.Rda",]
resultsum <- resultsum[resultsum$dat!="PRAD.Rda",]
resultswide <- resultswide[resultswide$dat!="PRAD.Rda",]
resultswide2 <- resultswide[,-1]
paramvalues <- paramvalues[results_withPRAD$dat!="PRAD.Rda"]
mtrys <- mtrys[results_withPRAD$dat!="PRAD.Rda"]





# Calculate ranks of the methods:

resultranks <- t(apply(resultswide2, 1, function(x) rank(-x)))

colnames(resultranks) <- gsub("cindex.", "", colnames(resultranks))



resultranks2 <- reshape(data.frame(resultranks), varying=colnames(resultranks), 
                        v.names="rank", 
                        timevar="method", times=colnames(resultranks),
                        direction="long")
resultranks2$method <- factor(resultranks2$method, levels=c("RSF", 
                                                            "VarProb",
                                                            "SplitWeights",
                                                            "BlockVarSel",
                                                            "RandomBlock",
                                                            "BlockForest"))

datasets <- datasets[datasets!="PRAD.Rda"]







# Figure: Clinical covariates plus RNA measurements: C index values obtained for the individual repetitions 
# of the cross-validation separately for each data set and method:


resultsumtemp <- resultsum
datasetstemp <- datasets

resultsumtemp$dat <- gsub(".Rda", "", resultsumtemp$dat)
datasetstemp <- gsub(".Rda", "", datasetstemp)

library("ggplot2")
p <- ggplot(data=resultsumtemp[resultsumtemp$dat %in% datasetstemp[1:10],], aes(x=method, y=cindex)) + facet_wrap(~dat, ncol=2, scales = 'free_y') + 
  geom_boxplot() + theme_bw() + theme(strip.text.x=element_text(size=14)) + labs(y="C index values") + 
  theme(axis.text.x=element_text(size=14, angle=45, vjust=1, hjust=1, colour="black"),
        axis.text.y=element_text(size=11, colour="black"), axis.title.x=element_blank(),
        axis.title.y=element_text(size=14))
p

ggsave("./suppmat2_hornungwrighttr/Figures/Results_AnalysisClusterTwoBlocks_1.pdf", width=6.5*1.35, height=8*1.35)



library("ggplot2")
p <- ggplot(data=resultsumtemp[resultsumtemp$dat %in% datasetstemp[11:20],], aes(x=method, y=cindex)) + facet_wrap(~dat, ncol=2, scales = 'free_y') + 
  geom_boxplot() + theme_bw() + theme(strip.text.x=element_text(size=14)) + labs(y="C index values") + 
  theme(axis.text.x=element_text(size=14, angle=45, vjust=1, hjust=1, colour="black"),
        axis.text.y=element_text(size=11, colour="black"), axis.title.x=element_blank(),
        axis.title.y=element_text(size=14))
p

ggsave("./suppmat2_hornungwrighttr/Figures/Results_AnalysisClusterTwoBlocks_2.pdf", width=6.5*1.35, height=8*1.35)





# Mean ranks:


round(sort(colMeans(resultranks)), 2)




# one-sided paired Student's t-tests to compare the performance each variant against RSF:


variants <- c("cindex.VarProb", "cindex.SplitWeights", "cindex.BlockVarSel", "cindex.RandomBlock", "cindex.BlockForest")

ps <- sapply(variants, function(x) t.test(resultswide[, x], resultswide[,"cindex.RSF"], paired=TRUE, alternative="greater")$p.value)

# Adjust the p values:
psadj <- p.adjust(p=ps, method = "holm")
psadj




# Comparison of BlockForest and RandomBlock with RSF:

sum(resultswide2[,"cindex.BlockForest"] > resultswide2[,"cindex.RSF"])
mean(resultswide2[,"cindex.BlockForest"] > resultswide2[,"cindex.RSF"])

sum(resultswide2[,"cindex.RandomBlock"] > resultswide2[,"cindex.RSF"])
mean(resultswide2[,"cindex.RandomBlock"] > resultswide2[,"cindex.RSF"])




# Figure: Clinical covariates plus RNA measurements: Performances of 
# all six considered methods:


library("RColorBrewer")

resultsumsumtemp <- resultsumsum
resultsumsumtemp$dat

datasetlevels <- resultsumsumtemp[resultsumsumtemp$method=="RSF",]$dat[order(resultsumsumtemp[resultsumsumtemp$method=="RSF",]$cindex)]

resultsumsumtemp$dat <- factor(resultsumsumtemp$dat, levels=datasetlevels)

gg_color_hue <- function(n) {
  hues = seq(15, 375, length = n + 1)
  hcl(h = hues, l = 65, c = 100)[1:n]
}

p1 <- ggplot(data=resultsumsumtemp, aes(x=method, y=cindex)) + theme_bw() + 
  geom_line(aes(group=dat, color=dat, linetype=dat)) + ylab("Mean C index values") + 
  scale_linetype_manual(values = c(rep("12345678", 5), rep("solid", 5), rep("dotted", 5), rep("dashed", 5))) + # scale_linetype_manual(values = c(rep("solid", 5), rep("longdash", 5), rep("dotted", 5), rep("dotdash", 5))) +
  scale_color_manual(values = rep(gg_color_hue(5), times=4)) +
  geom_boxplot(fill="transparent") + ggtitle("    a") +
  theme(axis.title.x=element_blank(), axis.text.x=element_text(size=14, angle=45, vjust=1, hjust=1, colour="black"),
        axis.text.y=element_text(size=11, colour="black"), axis.title=element_text(size=14), legend.position="none",
        plot.title = element_text(size = 25, face = "bold"))
p1

resultsumsumtemp2 <- resultsumsumtemp 
datstemp <- unique(resultsumsumtemp$dat)
for(i in seq(along=datstemp)) {
  rsfc <- resultsumsumtemp2$cindex[resultsumsumtemp2$method=="RSF" & resultsumsumtemp2$dat==datstemp[i]]
  resultsumsumtemp2$cindex[resultsumsumtemp2$dat==datstemp[i]] <- resultsumsumtemp2$cindex[resultsumsumtemp2$dat==datstemp[i]] - rsfc
}

resultsumsumtemp2$dat <- factor(resultsumsumtemp2$dat, levels=datasetlevels)

p2 <- ggplot(data=resultsumsumtemp2, aes(x=method, y=cindex)) + theme_bw() + 
  geom_line(aes(group=dat, color=dat, linetype=dat)) + ylab("Differences between the mean C index values obtained\nfor the variants and the reference method RSF") + 
  geom_hline(yintercept=0, col="darkgrey", size=1) +
  scale_linetype_manual(values = c(rep("12345678", 5), rep("solid", 5), rep("dotted", 5), rep("dashed", 5))) + # scale_linetype_manual(values = c(rep("solid", 5), rep("longdash", 5), rep("dotted", 5), rep("dotdash", 5))) +
  scale_color_manual(values = rep(gg_color_hue(5), times=4)) +
  geom_boxplot(fill="transparent") + ggtitle("b") +
  theme(axis.title.x=element_blank(), axis.text.x=element_text(size=14, angle=45, vjust=1, hjust=1, colour="black"),
        axis.text.y=element_text(size=11, colour="black"), axis.title=element_text(size=14), legend.position="none",
        plot.title = element_text(size = 25, face = "bold"))
p2

set.seed(1234)
p3 <- ggplot(data=resultranks2, aes(x=method, y=rank)) + theme_bw() + geom_boxplot() + 
  ylab("Data set specific ranks") + ggtitle("    c") +
  theme(axis.title.x=element_blank(), axis.text.x=element_text(size=14, angle=45, vjust=1, hjust=1, colour="black"),
        axis.text.y=element_text(size=11, colour="black"), axis.title=element_text(size=14),
        plot.title = element_text(size = 25, face = "bold"))
p3

library("grid")
library("gridExtra")
pall <- grid.arrange(p1, p2, p3, ncol = 1)

grid.draw(pall)

ggsave(file="./suppmat2_hornungwrighttr/Figures/Figure3.pdf", plot=pall, width=7.5, height=14)






# Figure: Clinical covariates plus RNA measurements: Performances of BlockForest and RandomBlock relative to that of RSF.


dataordered <- resultswide$dat[order(resultswide[,"cindex.BlockForest"] - resultswide[,"cindex.RSF"])]
dataordered <- gsub(".Rda", "", dataordered)

dataordered <- factor(dataordered, levels=dataordered)

datatemp <- data.frame(x=dataordered, y1=sort(resultswide[,"cindex.BlockForest"] - resultswide[,"cindex.RSF"]),
                       y2=sapply(paste(as.character(dataordered), ".Rda", sep=""), function(x) resultswide$cindex.RandomBlock[resultswide$dat==x] -
                                   resultswide$cindex.RSF[resultswide$dat==x]))

datatemp <- reshape(datatemp, varying=c("y1", "y2"), 
                    v.names="difference", 
                    timevar="Method", times=c("BlockForest", "RandomBlock"),
                    direction="long")


p <- ggplot(data=datatemp, aes(x=x, y=difference)) + theme_bw() + geom_hline(yintercept=0, col="grey", size=1) + 
  geom_point(aes(color=Method)) + labs(x="data set", y="Differences between mean C index values\nobtained for BlockForest / RandomBlock and RSF") +  
  theme(axis.text.x=element_text(size=12, angle=45, vjust=1, hjust=1, colour="black"),
        axis.text.y=element_text(size=12),
        axis.title.x=element_blank(),
        axis.title.y=element_text(size=14),
        legend.title=element_text(size=14), 
        legend.text=element_text(size=14))
p

ggsave("./suppmat2_hornungwrighttr/Figures/Figure4.pdf", width=12*0.85, height=6.5*0.85)








# Figures: Clinical covariates plus RNA measurements: tuning parameter values optimized for the different variants:



resultsparamvalues <- results

cvalbool <- sapply(paramvalues, function(x) all(!is.na(unlist(x))))
resultsparamvalues <- results[cvalbool,]
paramvaluesnoNA <- paramvalues[cvalbool]

alldata <- sort(unique(resultsparamvalues$dat))

resultsparamvalues$cval_clin <- sapply(paramvaluesnoNA, function(x) x[1])
resultsparamvalues$cval_rna <- sapply(paramvaluesnoNA, function(x) x[2])




load("./suppmat2_hornungwrighttr/Data/numbercovariates.Rda")

numbercovariates <- numbercovariates[rownames(numbercovariates)!="PRAD.Rda",]

numbercovariates <- numbercovariates[,c("clin", "rna")]


for(i in 1:nrow(numbercovariates)) {
  ncovs <- numbercovariates[i,]
  restemp <- resultsparamvalues[resultsparamvalues$dat==rownames(numbercovariates)[i] & 
                              resultsparamvalues$method=="VarProb",][,c("cval_clin", "cval_rna")]
  resultsparamvalues[resultsparamvalues$dat==rownames(numbercovariates)[i] &
                   resultsparamvalues$method=="VarProb",][,c("cval_clin", "cval_rna")] <-
    t(apply(restemp, 1, function(x) x/sum(ncovs*x, na.rm=TRUE)))
}





methods <- c("VarProb",
             "SplitWeights", 
             "BlockVarSel",
             "RandomBlock", 
             "BlockForest")

alldatatemp <- gsub(".Rda", "", alldata) 


i <- 1

resultsparamvaluestemp <- resultsparamvalues[resultsparamvalues$method==methods[i],]
resultsparamvaluestempsafe <- resultsparamvaluestemp

resultsparamvaluestemp <- reshape(resultsparamvaluestemp, varying=c("cval_clin", "cval_rna"), 
                              v.names="cval", 
                              timevar="block", times=c("clin", "rna"),
                              direction="long")

resultsparamvaluestemp$dat <- gsub(".Rda", "", resultsparamvaluestemp$dat)

library("ggplot2")
p <- ggplot(data=resultsparamvaluestemp[resultsparamvaluestemp$dat %in% alldatatemp[1:10],], aes(x=block, y=cval)) + facet_wrap(~dat, ncol=2, scales = 'free_y') + 
  geom_boxplot() + theme_bw() + theme(strip.text.x=element_text(size=14)) + labs(x="Block", y="Tuning parameter values") + 
  theme(axis.text.x=element_text(size=14, angle=45, vjust=1, hjust=1, colour="black"),
        axis.text.y=element_text(size=11, colour="black"), axis.title=element_text(size=14))
p

ggsave(paste("./suppmat2_hornungwrighttr/Figures/TunParamTwoBlocks_", methods[i], "_1.pdf", sep=""), width=6*1.4, height=8*1.4)


p <- ggplot(data=resultsparamvaluestemp[resultsparamvaluestemp$dat %in% alldatatemp[11:20],], aes(x=block, y=cval)) + facet_wrap(~dat, ncol=2, scales = 'free_y') + 
  geom_boxplot() + theme_bw() + theme(strip.text.x=element_text(size=14)) + labs(x="Block", y="Tuning parameter values") + 
  theme(axis.text.x=element_text(size=14, angle=45, vjust=1, hjust=1, colour="black"),
        axis.text.y=element_text(size=11, colour="black"), axis.title=element_text(size=14))
p

ggsave(paste("./suppmat2_hornungwrighttr/Figures/TunParamTwoBlocks_", methods[i], "_2.pdf", sep=""), width=6*1.4, height=7*1.4)



# The values of the optimized selection probabilities associated with VarProb
# are for all data sets larger for the clinical block than those for the RNA block:

library("plyr")
resultsparamvaluestempsum <- ddply(resultsparamvaluestemp, .variables=c("method", "dat", "block"), .fun=summarise, cval=mean(cval, na.rm=TRUE))

resultsparamvaluestempsumclin <- resultsparamvaluestempsum[resultsparamvaluestempsum$block=="clin",]
resultsparamvaluestempsumrna <- resultsparamvaluestempsum[resultsparamvaluestempsum$block=="rna",]

all(resultsparamvaluestempsumclin$cval > resultsparamvaluestempsumrna$cval)





i <- 2

resultsparamvaluestemp <- resultsparamvalues[resultsparamvalues$method==methods[i],]
resultsparamvaluestempsafe <- resultsparamvaluestemp

resultsparamvaluestemp <- reshape(resultsparamvaluestemp, varying=c("cval_clin", "cval_rna"), 
                              v.names="cval", 
                              timevar="block", times=c("clin", "rna"),
                              direction="long")

resultsparamvaluestemp$dat <- gsub(".Rda", "", resultsparamvaluestemp$dat)

p <- ggplot(data=resultsparamvaluestemp[resultsparamvaluestemp$dat %in% alldatatemp[1:10],], aes(x=block, y=cval)) + facet_wrap(~dat, ncol=2, scales = 'free_y') + 
  geom_boxplot() + theme_bw() + theme(strip.text.x=element_text(size=14)) + labs(x="Block", y="Tuning parameter values") + 
  theme(axis.text.x=element_text(size=14, angle=45, vjust=1, hjust=1, colour="black"),
        axis.text.y=element_text(size=11, colour="black"), axis.title=element_text(size=14))
p

ggsave(paste("./suppmat2_hornungwrighttr/Figures/TunParamTwoBlocks_", methods[i], "_1.pdf", sep=""), width=6*1.4, height=8*1.4)


p <- ggplot(data=resultsparamvaluestemp[resultsparamvaluestemp$dat %in% alldatatemp[11:20],], aes(x=block, y=cval)) + facet_wrap(~dat, ncol=2, scales = 'free_y') + 
  geom_boxplot() + theme_bw() + theme(strip.text.x=element_text(size=14)) + labs(x="Block", y="Tuning parameter values") + 
  theme(axis.text.x=element_text(size=14, angle=45, vjust=1, hjust=1, colour="black"),
        axis.text.y=element_text(size=11, colour="black"), axis.title=element_text(size=14))
p

ggsave(paste("./suppmat2_hornungwrighttr/Figures/TunParamTwoBlocks_", methods[i], "_2.pdf", sep=""), width=6*1.4, height=7*1.4)





i <- 3

resultsparamvaluestemp <- resultsparamvalues[resultsparamvalues$method==methods[i],]
resultsparamvaluestempsafe <- resultsparamvaluestemp

resultsparamvaluestemp <- reshape(resultsparamvaluestemp, varying=c("cval_clin", "cval_rna"), 
                              v.names="cval", 
                              timevar="block", times=c("clin", "rna"),
                              direction="long")

resultsparamvaluestemp$dat <- gsub(".Rda", "", resultsparamvaluestemp$dat)

p <- ggplot(data=resultsparamvaluestemp[resultsparamvaluestemp$dat %in% alldatatemp[1:10],], aes(x=block, y=cval)) + facet_wrap(~dat, ncol=2, scales = 'free_y') + 
  geom_boxplot() + theme_bw() + theme(strip.text.x=element_text(size=14)) + labs(x="Block", y="Tuning parameter values") + 
  theme(axis.text.x=element_text(size=14, angle=45, vjust=1, hjust=1, colour="black"),
        axis.text.y=element_text(size=11, colour="black"), axis.title=element_text(size=14))
p

ggsave(paste("./suppmat2_hornungwrighttr/Figures/TunParamTwoBlocks_", methods[i], "_1.pdf", sep=""), width=6*1.4, height=8*1.4)


p <- ggplot(data=resultsparamvaluestemp[resultsparamvaluestemp$dat %in% alldatatemp[11:20],], aes(x=block, y=cval)) + facet_wrap(~dat, ncol=2, scales = 'free_y') + 
  geom_boxplot() + theme_bw() + theme(strip.text.x=element_text(size=14)) + labs(x="Block", y="Tuning parameter values") + 
  theme(axis.text.x=element_text(size=14, angle=45, vjust=1, hjust=1, colour="black"),
        axis.text.y=element_text(size=11, colour="black"), axis.title=element_text(size=14))
p

ggsave(paste("./suppmat2_hornungwrighttr/Figures/TunParamTwoBlocks_", methods[i], "_2.pdf", sep=""), width=6*1.4, height=7*1.4)






i <- 4

resultsparamvaluestemp <- resultsparamvalues[resultsparamvalues$method==methods[i],]
resultsparamvaluestempsafe <- resultsparamvaluestemp

resultsparamvaluestemp <- reshape(resultsparamvaluestemp, varying=c("cval_clin", "cval_rna"), 
                              v.names="cval", 
                              timevar="block", times=c("clin", "rna"),
                              direction="long")

resultsparamvaluestemp$dat <- gsub(".Rda", "", resultsparamvaluestemp$dat)

p <- ggplot(data=resultsparamvaluestemp[resultsparamvaluestemp$dat %in% alldatatemp[1:10],], aes(x=block, y=cval)) + facet_wrap(~dat, ncol=2, scales = 'free_y') + 
  geom_boxplot() + theme_bw() + theme(strip.text.x=element_text(size=14)) + labs(x="Block", y="Tuning parameter values") + 
  theme(axis.text.x=element_text(size=14, angle=45, vjust=1, hjust=1, colour="black"),
        axis.text.y=element_text(size=11, colour="black"), axis.title=element_text(size=14))
p

ggsave(paste("./suppmat2_hornungwrighttr/Figures/TunParamTwoBlocks_", methods[i], "_1.pdf", sep=""), width=6*1.4, height=8*1.4)


p <- ggplot(data=resultsparamvaluestemp[resultsparamvaluestemp$dat %in% alldatatemp[11:20],], aes(x=block, y=cval)) + facet_wrap(~dat, ncol=2, scales = 'free_y') + 
  geom_boxplot() + theme_bw() + theme(strip.text.x=element_text(size=14)) + labs(x="Block", y="Tuning parameter values") + 
  theme(axis.text.x=element_text(size=14, angle=45, vjust=1, hjust=1, colour="black"),
        axis.text.y=element_text(size=11, colour="black"), axis.title=element_text(size=14))
p

ggsave(paste("./suppmat2_hornungwrighttr/Figures/TunParamTwoBlocks_", methods[i], "_2.pdf", sep=""), width=6*1.4, height=7*1.4)



# Additional analysis of the block selection probabilites optimized using RandomBlock:

# In the median, the block selection probability of the RNA block was
# 3.7 higher than that of the clinical block.

library("plyr")
resultsparamvaluestempsum <- ddply(resultsparamvaluestemp, .variables=c("method", "dat", "block"), .fun=summarise, cval=mean(cval, na.rm=TRUE))

boxplot(sapply(unique(resultsparamvaluestempsum$dat), function(x) resultsparamvaluestempsum$cval[(resultsparamvaluestempsum$block=="rna") & (resultsparamvaluestempsum$dat==x)]/
       resultsparamvaluestempsum$cval[(resultsparamvaluestempsum$block=="clin") & (resultsparamvaluestempsum$dat==x)]))

median(sapply(unique(resultsparamvaluestempsum$dat), function(x) resultsparamvaluestempsum$cval[(resultsparamvaluestempsum$block=="rna") & (resultsparamvaluestempsum$dat==x)]/
              resultsparamvaluestempsum$cval[(resultsparamvaluestempsum$block=="clin") & (resultsparamvaluestempsum$dat==x)]))



# Mean block selection probabilities:

round(tapply(resultsparamvaluestempsum$cval, resultsparamvaluestempsum$block, mean), 2)





i <- 5

resultsparamvaluestemp <- resultsparamvalues[resultsparamvalues$method==methods[i],]
resultsparamvaluestempsafe <- resultsparamvaluestemp

resultsparamvaluestemp <- reshape(resultsparamvaluestemp, varying=c("cval_clin", "cval_rna"), 
                              v.names="cval", 
                              timevar="block", times=c("clin", "rna"),
                              direction="long")

resultsparamvaluestemp$dat <- gsub(".Rda", "", resultsparamvaluestemp$dat)

p <- ggplot(data=resultsparamvaluestemp[resultsparamvaluestemp$dat %in% alldatatemp[1:10],], aes(x=block, y=cval)) + facet_wrap(~dat, ncol=2, scales = 'free_y') + 
  geom_boxplot() + theme_bw() + theme(strip.text.x=element_text(size=14)) + labs(x="Block", y="Tuning parameter values") + 
  theme(axis.text.x=element_text(size=14, angle=45, vjust=1, hjust=1, colour="black"),
        axis.text.y=element_text(size=11, colour="black"), axis.title=element_text(size=14))
p

ggsave(paste("./suppmat2_hornungwrighttr/Figures/TunParamTwoBlocks_", methods[i], "_1.pdf", sep=""), width=6*1.4, height=8*1.4)


p <- ggplot(data=resultsparamvaluestemp[resultsparamvaluestemp$dat %in% alldatatemp[11:20],], aes(x=block, y=cval)) + facet_wrap(~dat, ncol=2, scales = 'free_y') + 
  geom_boxplot() + theme_bw() + theme(strip.text.x=element_text(size=14)) + labs(x="Block", y="Tuning parameter values") + 
  theme(axis.text.x=element_text(size=14, angle=45, vjust=1, hjust=1, colour="black"),
        axis.text.y=element_text(size=11, colour="black"), axis.title=element_text(size=14))
p

ggsave(paste("./suppmat2_hornungwrighttr/Figures/TunParamTwoBlocks_", methods[i], "_2.pdf", sep=""), width=6*1.4, height=7*1.4)







# Figure: Clinical covariates plus RNA measurements: Differences between the mean C index values obtained using BlockForest
# and that obtained using RSF plotted against the values of 'n' (left panel), 
# 'b_clin' (middle panel), and 'signal' (right panel).


alldata <- sort(unique(resultsumsum$dat))


# The following code is commented out, because for
# this part the processed data files would be necessary,
# which are, however, not available with the Electronic
# Appendix (available upon request).
# However, the result of this part is stored as an
# Rda files in the subfolder "Results" of the Electronic
# Appendix, which is why the code following this out-commented
# part is still executable.


# datasetlist <- list()
# blocknamesavall <- list()
# 
# try(rm(clin))
# try(rm(mirna))
# try(rm(mutation))
# try(rm(cnv))
# try(rm(rna))
# gc()
# 
# for(i in seq(along=alldata)) {
#   
#   
#   load(paste("./suppmat2_hornungwrighttr/Data/ProcessedData/", alldata[i], sep=""))
#   
#   blocknames <- c("clin", 
#                   "mirna",
#                   "mutation",
#                   "cnv",
#                   "rna")
#   
#   blocknamesav <-  c("")
#   
#   if(class(try(ncol(clin)))!="try-error")
#     blocknamesav <- c(blocknamesav, "clin")
#   if(class(try(ncol(mirna)))!="try-error")
#     blocknamesav <- c(blocknamesav, "mirna")
#   if(class(try(ncol(mutation)))!="try-error")
#     blocknamesav <- c(blocknamesav, "mutation")
#   if(class(try(ncol(cnv)))!="try-error")
#     blocknamesav <- c(blocknamesav, "cnv")
#   if(class(try(ncol(rna)))!="try-error")
#     blocknamesav <- c(blocknamesav, "rna")  
#   
#   blocknamesav <- blocknamesav[-1]
#   
#   blocknamesavall[[i]] <- blocknamesav
#   
#   eval(parse(text=paste("datasetlist[[i]] <- list(targetvar, ", paste(blocknamesav, collapse=", "), ")", sep="")))
#   eval(parse(text=paste("names(datasetlist[[i]]) <- c(\"targetvar\", \"", paste(blocknamesav, collapse="\", \""), "\")", sep="")))
# 
#   
#   try(rm(clin))
#   try(rm(mirna))
#   try(rm(mutation))
#   try(rm(cnv))
#   try(rm(rna))
#   gc()
#   
#   cat(i, "\n")
#   
# }
# 
# names(datasetlist) <- alldata
# 
# 
# 
# 
# resultstemp <- resultsparamvalues[resultsparamvalues$method=="RandomBlock",]
# 
# resultstemp$method <- resultstemp$cvfoldind <- resultstemp$cvind <- resultstemp$cindex <- resultstemp$mtry <- NULL
# 
# library("plyr")
# resultstempsum <- ddply(resultstemp, .variables=c("dat"), .fun=summarise, cval_clin=mean(cval_clin, na.rm=TRUE), 
#                         cval_rna=mean(cval_rna, na.rm=TRUE))
# 
# 
# resultstempsum$maxprob <- apply(resultstempsum[,2:3], 1, max, na.rm=TRUE)
# 
# resultstempsum$cindex.BlockForest <- resultswide$cindex.BlockForest[sapply(resultstempsum$dat, function(x) which(resultswide$dat==x))]
# resultstempsum$cindex.RandomBlock <- resultswide$cindex.RandomBlock[sapply(resultstempsum$dat, function(x) which(resultswide$dat==x))]
# resultstempsum$cindex.RSF <- resultswide$cindex.RSF[sapply(resultstempsum$dat, function(x) which(resultswide$dat==x))]
# 
# resultstempsum$n <- sapply(resultstempsum$dat, function(x) nrow(datasetlist[names(datasetlist)==x][[1]]$targetvar))
# 
# resultstempsum$cindex.MeanRSFRandomBlock <- apply(resultswide[,c("cindex.RSF", "cindex.RandomBlock")], 1, mean, na.rm=TRUE)[sapply(resultstempsum$dat, function(x) which(resultswide$dat==x))]
# resultstempsum$cindex.MeanRSFBlockForest <- apply(resultswide[,c("cindex.RSF", "cindex.BlockForest")], 1, mean, na.rm=TRUE)[sapply(resultstempsum$dat, function(x) which(resultswide$dat==x))]
# 
# save(resultstempsum, file="./suppmat2_hornungwrighttr/Results/resultstempsum_twoblocks.Rda")


# Load the result of the out-commented part above:

load("./suppmat2_hornungwrighttr/Results/resultstempsum_twoblocks.Rda")




x <- resultstempsum$cval_clin
y <- resultstempsum$cindex.BlockForest - resultstempsum$cindex.RSF

pred <- loess.smooth(x, y)
dataloess <- data.frame(x=pred$x, y=pred$y)

p2 <- ggplot(resultstempsum, aes(x=cval_clin, y=cindex.BlockForest - cindex.RSF)) + theme_bw() + geom_point() + 
  geom_hline(yintercept=0, col="grey") +
  geom_line(data=dataloess, aes(x=x, y=y), col="blue") + ggtitle(expression(paste("Influence of '", b["clin"], "'", sep=""))) + labs(x=expression(b["clin"]), y="diffC") +
  theme(plot.title = element_text(size=16), axis.title=element_text(size=15), axis.text=element_text(size=11))

p2


x <- resultstempsum$n
y <- resultstempsum$cindex.BlockForest - resultstempsum$cindex.RSF

pred <- loess.smooth(x, y)
dataloess <- data.frame(x=pred$x, y=pred$y)

p1 <- ggplot(resultstempsum, aes(x=n, y=cindex.BlockForest - cindex.RSF)) + theme_bw() + geom_point() + 
  geom_hline(yintercept=0, col="grey") +
  geom_line(data=dataloess, aes(x=x, y=y), col="blue") + ggtitle("Influence of 'n'") + ylab("diffC") +
  theme(plot.title = element_text(size=16), axis.title=element_text(size=15), axis.text=element_text(size=11))

p1


x <- resultstempsum$cindex.MeanRSFBlockForest
y <- resultstempsum$cindex.BlockForest - resultstempsum$cindex.RSF

pred <- loess.smooth(x, y)
dataloess <- data.frame(x=pred$x, y=pred$y)

p3 <- ggplot(resultstempsum, aes(x=cindex.MeanRSFBlockForest, y=cindex.BlockForest - cindex.RSF)) + theme_bw() + geom_point() + 
  geom_hline(yintercept=0, col="grey") +
  geom_line(data=dataloess, aes(x=x, y=y), col="blue") + ggtitle("Influence of 'signal'") + labs(x="signal", y="diffC") +
  theme(plot.title = element_text(size=16), axis.title=element_text(size=15), axis.text=element_text(size=11))

p3

library("grid")
library("gridExtra")
pall <- grid.arrange(p1, p2, p3, ncol = 3)

grid.draw(pall)

ggsave(file="./suppmat2_hornungwrighttr/Figures/FactorsDifferenceInPerformanceTwoBlocks.pdf", plot=pall, width=14*0.75, height=5*0.75)
